@@ -16,7 +16,7 @@ from mldock.config_managers.core import BaseConfigManager
 from mldock.platform_helpers.mldock import utils as mldock_utils
 from mldock.platform_helpers import utils
 
-logger=logging.getLogger('mldock')
+logger = logging.getLogger('mldock')
 
 class MLDockConfigManager(BaseConfigManager):
     """Hyperparameter Config Manager for mldock
@@ -25,20 +25,23 @@ class MLDockConfigManager(BaseConfigManager):
     config = {
         "image_name": None,
         "template": "generic",
-        "requirements_dir": "src/requirements.txt",
+        "requirements_dir": "src",
         "mldock_module_dir": "src",
         "container_dir": "container",
-        "data": list(),
-        "environment": dict(),
-        "hyperparameters": dict(),
-        "model": list(),
-        "stages": dict(),
+        "data": [],
+        "environment": {},
+        "hyperparameters": {},
+        "model": [],
+        "stages": {},
     }
 
-    def __init__(self, filepath: str, create: bool = False):
+    available_templates = None
+
+    def __init__(self, filepath: str, create: bool = False, **kwargs):
         # dealing with weird os related path formats
         super().__init__()
         self.filepath = filepath
+        self.available_templates = kwargs.get('available_templates', None)
 
         config = self.load_config(self.filepath, create=create)
 
@@ -98,7 +101,8 @@ class MLDockConfigManager(BaseConfigManager):
         """
 
         click.secho("Set container template name", bg='blue', nl=True)
-        options = ['generic', 'gcp', 'aws']
+        # would be awesome to fetch this from the template dir
+        options = self.available_templates
 
         template_name = click.prompt(
             text=style_dropdown(
@@ -225,7 +229,7 @@ class MLDockConfigManager(BaseConfigManager):
         )
 
         self.config.update({
-            'requirements_dir':requirements_file_name
+            'requirements_dir': requirements_file_name
         })
 
     def update_stages(self, stages: dict):
