@@ -18,7 +18,11 @@ class AWSEnvironment(base.BaseEnvironment):
     def setup_inputs(self):
         """ Iterates and downloads assets remoate -> input channels
         """
-        logger.info("Setup assets in {}".format(self.input_data_dir))
+        logger.info((
+            "Setup assets in {INPUT_DATA_DIR}".format(
+                INPUT_DATA_DIR=self.input_data_dir
+            )
+        ))
         # only fetch channels of environment prefix MLDOCK_INPUT_CHANNEL_
         channels = self.get_input_channel_iter()
 
@@ -34,13 +38,20 @@ class AWSEnvironment(base.BaseEnvironment):
                     scheme='s3'
                 )
 
-            except FileExistsError as exception:
-                logger.info("{} Channel skipped. Already exists".format(channel['key']))
+            except FileExistsError:
+                logger.info((
+                    "{CHANNEL_KEY} Channel skipped. "
+                    "Already exists".format(CHANNEL_KEY=channel['key'])
+                ))
 
     def cleanup_outputs(self):
         """ Iterates and uploads output channel -> remote
         """
-        logger.info("Cleanup assets in {}".format(self.output_data_dir))
+        logger.info((
+            "Cleanup assets in {OUTPUT_DATA_DIR}".format(
+                OUTPUT_DATA_DIR=self.output_data_dir
+            )
+        ))
         # only fetch channels of environment prefix MLDOCK_OUTPUT_CHANNEL_
         channels = self.get_output_channel_iter()
 
@@ -57,18 +68,18 @@ class AWSEnvironment(base.BaseEnvironment):
                     storage_dir_path=channel['value'],
                     scheme='s3'
                 )
-            except AssertionError as exception:
+            except AssertionError:
                 logger.info(
-                     "Skipping channel. {} is not a "
-                     "directory or could not be found".format(
-                         local_channel_path
+                    "Skipping channel. {LOCAL_CHANNEL_PATH} is not a "
+                    "directory or could not be found".format(
+                        LOCAL_CHANNEL_PATH=local_channel_path
                     )
                 )
 
     def setup_model_artifacts(self):
         """ Iterates and downloads assets remoate -> model channel
         """
-        logger.info("Setup model assets in {}".format(self.model_dir))
+        logger.info("Setup model assets in {MODEL_DIR}".format(MODEL_DIR=self.model_dir))
         # only fetch channels of environment prefix MLDOCK_MODEL_INPUT_CHANNEL_
         channels = self.get_model_input_channel_iter()
 
@@ -83,13 +94,21 @@ class AWSEnvironment(base.BaseEnvironment):
                     scheme='s3'
                 )
 
-            except FileExistsError as exception:
-                logger.info("{} Channel skipped. Already exists".format(channel['key']))
+            except FileExistsError:
+                logger.info((
+                    "{CHANNEL_KEY} Channel skipped. Already exists".format(
+                        CHANNEL_KEY=channel['key']
+                    )
+                ))
 
     def cleanup_model_artifacts(self):
         """ Iterates and uploads from model channel -> remote
         """
-        logger.info("Cleanup model assets in {}".format(self.model_dir))
+        logger.info((
+            "Cleanup model assets in {MODEL_DIR}".format(
+                MODEL_DIR=self.model_dir
+            )
+        ))
 
         # only fetch channels of environment prefix MLDOCK_MODEL_OUTPUT_CHANNEL_
         channels = self.get_model_output_channel_iter()
@@ -107,10 +126,10 @@ class AWSEnvironment(base.BaseEnvironment):
                     storage_dir_path=channel['value'],
                     scheme='s3'
                 )
-            except AssertionError as exception:
+            except AssertionError:
                 logger.info(
-                     "Skipping channel. {} is not a "
-                     "directory or could not be found".format(
-                         local_channel_path
+                    "Skipping channel. {LOCAL_CHANNEL_PATH} is not a "
+                    "directory or could not be found".format(
+                        LOCAL_CHANNEL_PATH=local_channel_path
                     )
                 )
